pub enum PolicyError {
TooManyAncestors,
BelowMinRelayFee {
tx_rate: u64,
min_rate: u64,
},
AncestorSizeLimit,
TooManyDescendants,
}Expand description
Policy rejection reason for non-consensus mempool limits.
Variants
TooManyAncestors
The transaction would exceed the configured ancestor count limit.
BelowMinRelayFee
Transaction’s fee_rate is below the configured min-relay-fee floor.
Fields
AncestorSizeLimit
The transaction would exceed the configured ancestor package size limit.
TooManyDescendants
The transaction would exceed a configured descendant count limit.